@@ -124,7 +124,7 @@ class RandomEmail(Tube):
 
     def next(self):
         return ''.join(random.choice(string.ascii_lowercase)
-                       for x in range(self.length)) + self.domain
+                       for x in range(self.length)) + '@' + self.domain
 
 class BookTitle(Tube):
     def __init__(self, **kwargs):
